@@ -12,3 +12,5 @@ class Parameters(Enum):
     PARAM_MODEL_COST_FUNCTION = 'model_cost_function'
     PARAM_SYNC_COST_FUNCTION = 'sync_cost_function'
     PARAM_TRACE_NET_COSTS = "trace_net_costs"
+    PARAM_MAX_ALIGN_TIME = "max_align_time"
+    PARAM_MAX_ALIGN_TIME_TRACE = "max_align_time_trace"
