@@ -13,7 +13,7 @@ VERSIONS_TRACE = {CLASSIC: classic.apply_trace}
 
 
 @deprecation.deprecated(deprecated_in='1.3.0', removed_in='2.0.0', current_version='',
-                        details='Use algorithm entrypoint instead')
+                        details='Use algorithm entrypoint instead (conformance/log_skeleton/factory)')
 def apply(obj, model, variant=DEFAULT_VARIANT, parameters=None):
     """
     Apply log-skeleton based conformance checking given an event log/trace
