@@ -3,7 +3,8 @@ from collections import Counter
 from pm4py.algo.discovery.log_skeleton import trace_skel
 from pm4py.algo.discovery.log_skeleton.parameters import Parameters
 from pm4py.algo.discovery.log_skeleton.outputs import Outputs
-from pm4py.util import exec_utils
+from pm4py.util import exec_utils, constants
+from pm4py.objects.log.log import EventLog, Trace, Event
 
 
 def equivalence(logs_traces, all_activs, noise_threshold=0):
@@ -58,7 +59,7 @@ def always_after(logs_traces, all_activs, noise_threshold=0):
         for k in rs:
             rs[k] = rs[k] * logs_traces[trace]
         ret0 += rs
-    ret = set(x for x,y in ret0.items() if y >= all_activs[x[0]] * (1.0 - noise_threshold))
+    ret = set(x for x, y in ret0.items() if y >= all_activs[x[0]] * (1.0 - noise_threshold))
     return ret
 
 
@@ -86,7 +87,7 @@ def always_before(logs_traces, all_activs, noise_threshold=0):
         for k in rs:
             rs[k] = rs[k] * logs_traces[trace]
         ret0 += rs
-    ret = set(x for x,y in ret0.items() if y >= all_activs[x[0]] * (1.0 - noise_threshold))
+    ret = set(x for x, y in ret0.items() if y >= all_activs[x[0]] * (1.0 - noise_threshold))
     return ret
 
 
@@ -147,7 +148,7 @@ def directly_follows(logs_traces, all_activs, noise_threshold=0):
         for k in rs:
             rs[k] = rs[k] * logs_traces[trace]
         ret0 += rs
-    ret = set(x for x,y in ret0.items() if y >= all_activs[x[0]] * (1.0 - noise_threshold))
+    ret = set(x for x, y in ret0.items() if y >= all_activs[x[0]] * (1.0 - noise_threshold))
     return ret
 
 
@@ -183,13 +184,13 @@ def activ_freq(logs_traces, all_activs, len_log, noise_threshold=0):
                 ret0[act] = Counter()
             ret0[act][rs[act]] += logs_traces[trace]
     for act in ret0:
-        ret0[act] = sorted(list((x,y) for x,y in ret0[act].items()), key=lambda x: x[1], reverse=True)
+        ret0[act] = sorted(list((x, y) for x, y in ret0[act].items()), key=lambda x: x[1], reverse=True)
         added = 0
         i = 0
         while i < len(ret0[act]):
             added += ret0[act][i][1]
             if added >= (1.0 - noise_threshold) * len_log:
-                ret0[act] = ret0[act][:min(i+1, len(ret0[act]))]
+                ret0[act] = ret0[act][:min(i + 1, len(ret0[act]))]
             i = i + 1
         ret[act] = set(x[0] for x in ret0[act])
     return ret
@@ -226,8 +227,68 @@ def apply(log, parameters=None):
     ret[Outputs.EQUIVALENCE.value] = equivalence(logs_traces, all_activs, noise_threshold=noise_threshold)
     ret[Outputs.ALWAYS_AFTER.value] = always_after(logs_traces, all_activs, noise_threshold=noise_threshold)
     ret[Outputs.ALWAYS_BEFORE.value] = always_before(logs_traces, all_activs, noise_threshold=noise_threshold)
-    ret[Outputs.NEVER_TOGETHER.value] = never_together(logs_traces, all_activs, len(log), noise_threshold=noise_threshold)
+    ret[Outputs.NEVER_TOGETHER.value] = never_together(logs_traces, all_activs, len(log),
+                                                       noise_threshold=noise_threshold)
     ret[Outputs.DIRECTLY_FOLLOWS.value] = directly_follows(logs_traces, all_activs, noise_threshold=noise_threshold)
     ret[Outputs.ACTIV_FREQ.value] = activ_freq(logs_traces, all_activs, len(log), noise_threshold=noise_threshold)
 
     return ret
+
+
+def apply_from_variants_list(var_list, parameters=None):
+    """
+    Discovers the log skeleton from the variants list
+
+    Parameters
+    ---------------
+    var_list
+        Variants list
+    parameters
+        Parameters
+
+    Returns
+    ---------------
+    model
+        Log skeleton model
+    """
+    if parameters is None:
+        parameters = {}
+
+    activity_key = exec_utils.get_param_value(Parameters.ACTIVITY_KEY, parameters, xes.DEFAULT_NAME_KEY)
+    variant_delimiter = exec_utils.get_param_value(Parameters.PARAMETER_VARIANT_DELIMITER, parameters,
+                                                   constants.DEFAULT_VARIANT_SEP)
+
+    log = EventLog()
+    for cv in var_list:
+        v = cv[0]
+        tr = v.split(variant_delimiter)
+        trace = Trace()
+        for act in tr:
+            trace.append(Event({activity_key: act}))
+        log.append(trace)
+
+    return apply(log, parameters=parameters)
+
+
+def prepare_encode(log_skeleton):
+    """
+    Prepares the log skeleton for encoding
+
+    Parameters
+    --------------
+    log_skeleton
+        Log skeleton
+
+    Returns
+    --------------
+    log_skeleton
+        Log skeleton (with lists instead of sets)
+    """
+    log_skeleton[Outputs.EQUIVALENCE.value] = list(log_skeleton[Outputs.EQUIVALENCE.value])
+    log_skeleton[Outputs.ALWAYS_AFTER.value] = list(log_skeleton[Outputs.ALWAYS_AFTER.value])
+    log_skeleton[Outputs.ALWAYS_BEFORE.value] = list(log_skeleton[Outputs.ALWAYS_BEFORE.value])
+    log_skeleton[Outputs.NEVER_TOGETHER.value] = list(log_skeleton[Outputs.NEVER_TOGETHER.value])
+    log_skeleton[Outputs.DIRECTLY_FOLLOWS.value] = list(log_skeleton[Outputs.DIRECTLY_FOLLOWS.value])
+    for act in log_skeleton[Outputs.ACTIV_FREQ.value]:
+        log_skeleton[Outputs.ACTIV_FREQ.value][act] = list(log_skeleton[Outputs.ACTIV_FREQ.value][act])
+    return log_skeleton
