@@ -2,9 +2,17 @@ import numpy
 
 from pm4py.statistics.variants.log import get as variants_filter
 from pm4py.util import xes_constants as xes
-from pm4py.util import constants
+from enum import Enum
+from pm4py.util import constants, exec_utils
 
-BETA = "beta"
+
+class Parameters(Enum):
+    ACTIVITY_KEY = constants.PARAMETER_CONSTANT_ACTIVITY_KEY
+    RESOURCE_KEY = constants.PARAMETER_CONSTANT_RESOURCE_KEY
+    BETA = "beta"
+
+
+BETA = Parameters.BETA
 
 
 def apply(log, parameters=None):
@@ -17,7 +25,7 @@ def apply(log, parameters=None):
         Log
     parameters
         Possible parameters of the algorithm:
-            beta -> beta value as described in the Wil SNA paper
+            Parameters.BETA -> beta value as described in the Wil SNA paper
 
     Returns
     -----------
@@ -28,12 +36,11 @@ def apply(log, parameters=None):
     if parameters is None:
         parameters = {}
 
-    resource_key = parameters[
-        constants.PARAMETER_CONSTANT_RESOURCE_KEY] if constants.PARAMETER_CONSTANT_RESOURCE_KEY in parameters else xes.DEFAULT_RESOURCE_KEY
-    beta = parameters[BETA] if BETA in parameters else 0
+    resource_key = exec_utils.get_param_value(Parameters.RESOURCE_KEY, parameters, xes.DEFAULT_RESOURCE_KEY)
+    beta = exec_utils.get_param_value(Parameters.BETA, parameters, 0)
 
-    parameters_variants = {constants.PARAMETER_CONSTANT_ACTIVITY_KEY: resource_key,
-                           constants.PARAMETER_CONSTANT_ATTRIBUTE_KEY: resource_key}
+    parameters_variants = {variants_filter.Parameters.ACTIVITY_KEY: resource_key,
+                           variants_filter.Parameters.ATTRIBUTE_KEY: resource_key}
     variants_occ = {x: len(y) for x, y in variants_filter.get_variants(log, parameters=parameters_variants).items()}
     variants_resources = list(variants_occ.keys())
     resources = [x.split(",") for x in variants_resources]
