@@ -4,7 +4,7 @@ import deprecation
 
 from pm4py.objects.log.log import EventLog, Trace, Event
 from pm4py.objects.log.util import sorting
-from pm4py.util.dt_parsing import parser as dt_parse_factory
+from pm4py.util.dt_parsing import parser as dt_parser
 
 
 @deprecation.deprecated(deprecated_in='1.3.0', removed_in='2.0.0', current_version='',
@@ -33,7 +33,7 @@ def import_log(filename, parameters=None):
     if parameters is None:
         parameters = {}
 
-    date_parser = dt_parse_factory.get()
+    date_parser = dt_parser.get()
 
     timestamp_sort = False
     timestamp_key = "time:timestamp"
