@@ -4,8 +4,33 @@ from scipy.stats import triang as triangular
 import string
 import math
 import itertools
-import random
 from enum import Enum
+from itertools import accumulate as _accumulate, repeat as _repeat
+from bisect import bisect as _bisect
+import random
+
+
+def choices(population, weights=None, *, cum_weights=None, k=1):
+    """Return a k sized list of population elements chosen with replacement.
+    If the relative weights or cumulative weights are not specified,
+    the selections are made with equal probability.
+    """
+    n = len(population)
+    if cum_weights is None:
+        if weights is None:
+            _int = int
+            n += 0.0    # convert to float for a small speed improvement
+            return [population[_int(random.random() * n)] for i in _repeat(None, k)]
+        cum_weights = list(_accumulate(weights))
+    elif weights is not None:
+        raise TypeError('Cannot specify both weights and cumulative weights')
+    if len(cum_weights) != n:
+        raise ValueError('The number of weights does not match the population')
+    bisect = _bisect
+    total = cum_weights[-1] + 0.0   # convert to float
+    hi = n - 1
+    return [population[bisect(cum_weights, random.random() * total, 0, hi)]
+            for i in _repeat(None, k)]
 
 
 class Parameters(Enum):
@@ -126,7 +151,7 @@ class GeneratedTree(object):
     def select_operator(self):
         # add root operator, if probabilities are high enough
         # ordering of operator computation is sequence, choice, parallel, loop, or
-        operator = random.choices(["sequence", "choice", "parallel", "loop", "or"],
+        operator = choices(["sequence", "choice", "parallel", "loop", "or"],
                                   [self.parameters["sequence"], self.parameters["choice"], self.parameters["parallel"],
                                    self.parameters["loop"], self.parameters["or"]])
         return operator[0]
