@@ -1,9 +1,6 @@
-import deprecation
 import tempfile
 
 
-@deprecation.deprecated(deprecated_in='1.3.0', removed_in='2.0.0', current_version='',
-                        details='Use visualizer module instead.')
 def view(gviz):
     """
     View the diagram
