@@ -1,9 +1,10 @@
 from pm4py.visualization.petrinet.common import visualize
+from pm4py.visualization.petrinet.parameters import Parameters
 
 
 def apply(net, initial_marking, final_marking, log=None, aggregated_statistics=None, parameters=None):
     """
-    Apply method for Petri net visualization (useful for recall from factory; it calls the
+    Apply method for Petri net visualization (it calls the
     graphviz_visualization method)
 
     Parameters
